@@ -38,6 +38,13 @@ bootstrap_sd_sl <- function( TH, r, m, x, N, h0,
 # estimator
 # sl0 - slope estimate
 
+#### 
+# KZ 28-Mar-12
+# included on.exit function which restores warning settings to their
+# original state
+####
+
+
 # MAIN PROGRAM
 # First 6 arguments are mandatory
     if( missing("TH") || missing("r") || missing("m") || missing("x") ||
@@ -106,7 +113,15 @@ bootstrap_sd_sl <- function( TH, r, m, x, N, h0,
 
 # INITIAL ESTIMATE
 # initial estimates with bandiwdth h0
+
+# KZ 28-03-2012 included on.exit routine so that the warning settings are
+# restored when the function terminates even if interrupted by user
+
+warn.current <- getOption("warn")
+on.exit(options(warn = warn.current));
+
 options(warn=-1)
+
     f <- locglmfit( x, r, m, x, h0, FALSE, link, guessing, lapsing, K,
                     p, ker, maxiter, tol )$pfit;
 
@@ -149,8 +164,6 @@ options(warn=-1)
         sl_boot[i] <- threshold_slope( ftmp, X, TH )$slope;
      }
 
-options(warn=0)
-
     sd <- sqrt( var(sl_boot ) );
 	value <- NULL
     value$sd <- sd
